@@ -1,6 +1,6 @@
 # Copyright (c) 2010 Infrae. All rights reserved.
 # See also LICENSE.txt
-# $Id: __init__.py 41502 2010-04-26 12:29:38Z sylvain $
+# $Id: __init__.py 45693 2010-10-06 09:33:51Z sylvain $
 
 import zc.recipe.egg
 import zc.buildout.easy_install
@@ -30,7 +30,6 @@ class Recipe(object):
         self.output_dir = options.get('output', '').strip()
         self.output_package = options.get('output-package', '').strip()
         self.domain = options.get('domain', 'silva').strip()
-        paths = [p.strip() for p in options.get('extra_paths', '').split('\n')]
         self.egg = zc.recipe.egg.Egg(buildout, name, options)
 
     def install(self):
@@ -58,8 +57,8 @@ class Recipe(object):
 
         scripts.extend(
             zc.buildout.easy_install.scripts(
-                [('%s-merge'% self.name,
-                  'infrae.i18nextract.merge',
+                [('%s-manage'% self.name,
+                  'infrae.i18nextract.manage',
                   'egg_entry_point')],
                 ws, self.options['executable'],
                 self.buildout['buildout']['bin-directory'],
